@@ -1,3 +1,7 @@
+from ark_nlp.factory.predictor.base._predictor import Predictor
+from ark_nlp.factory.predictor.base._token_classification import TokenClassificationPredictor
+from ark_nlp.factory.predictor.base._sequence_classification import SequenceClassificationPredictor
+
 from ark_nlp.factory.predictor.text_classification import TCPredictor
 from ark_nlp.factory.predictor.text_match import TMPredictor
 from ark_nlp.factory.predictor.bio_named_entity_recognition import BIONERPredictor
@@ -5,4 +9,3 @@ from ark_nlp.factory.predictor.crf_named_entity_recognition import CRFNERPredict
 from ark_nlp.factory.predictor.biaffine_named_entity_recognition import BiaffineNERPredictor
 from ark_nlp.factory.predictor.span_named_entity_recognition import SpanNERPredictor
 from ark_nlp.factory.predictor.global_pointer_named_entity_recognition import GlobalPointerNERPredictor
-from ark_nlp.factory.predictor.casrel_relation_extraction import CasrelREPredictor
\ No newline at end of file
