@@ -4,14 +4,17 @@ from ark_nlp.dataset import SentenceClassificationDataset as BertTCDataset
 from ark_nlp.processor.tokenizer.transfomer import SentenceTokenizer as Tokenizer
 from ark_nlp.processor.tokenizer.transfomer import SentenceTokenizer as BertTCTokenizer
 
-from ark_nlp.nn import BertConfig as BertConfig
+from ark_nlp.nn import BertConfig
+from ark_nlp.nn import BertConfig as ModuleConfig
+
 from ark_nlp.nn import Bert
+from ark_nlp.nn import Bert as Module
 
 from ark_nlp.factory.optimizer import get_default_bert_optimizer as get_default_model_optimizer
 from ark_nlp.factory.optimizer import get_default_bert_optimizer as get_default_bert_optimizer
 
-from ark_nlp.factory.task import SequenceClassificationTask as Task
-from ark_nlp.factory.task import SequenceClassificationTask as BertTCTask
+from ark_nlp.factory.task import TCTask as Task
+from ark_nlp.factory.task import TCTask as BertTCTask
 
 from ark_nlp.factory.predictor import TCPredictor as Predictor
-from ark_nlp.factory.predictor import TCPredictor as BertTCPredictor
\ No newline at end of file
+from ark_nlp.factory.predictor import TCPredictor as BertTCPredictor
